\name{Mesonorm}
\title{Improved Mesonorm for granitoid rocks}
\alias{Mesonorm}

\description{
Calculates \emph{eine bessere} Mesonorm for granitoids of \emph{Mielke & Winkler (1979)}.
}

\usage{
    Mesonorm(WR, GUI = FALSE, precision = getOption("gcd.digits"))
}

\arguments{
    \item{WR}{a numerical matrix; the whole-rock data to be normalized.}
    \item{GUI}{logical, is the function called from the GUI?}
    \item{precision}{precision of the result.}
}

\details{
    This method of norm calculation should yield mineral proportions close to the 
    actual mode of granitoid rocks. The calculated components are:

    \preformatted{
    Orthoclase, Albite, Anorthite, Quartz, Apatite, Magnetite, 
    Hematite, Ilmenite, Biotite, Amphibole, Calcite, Corundum, 
    Rest
    }

    If desired, the function plots the Q'-ANOR diagram of 
    \emph{Streckeisen & Le Maitre (1979)}
    using the function \code{\link{QANOR}}. 
}
 
\references{
Mielke P & Winkler HGF (1979) Eine bessere Berechnung der Mesonorm fuer 
granitische Gesteine. Neu Jb Mineral, Mh 471-480

Streckeisen A & Le Maitre RW (1979) A chemical approximation to the modal 
QAPF classification of the igneous rocks. Neu Jb Mineral, Abh 136: 169-206
}

\examples{
    data(sazava)
    accessVar("sazava")
    Mesonorm(WR)
}

\value{
A numeric matrix '\code{results}'. 
}

\seealso{
  \link{QANOR}
}

\keyword{manip}
\concept{Menu: Calculations}
\concept{Calculation}
\concept{Norm}

\author{
    Vojtech Janousek, \email{vojtech.janousek@geology.cz} 
}
