\encoding{utf8}
\name{phasePropPlot}
\alias{phasePropPlot}

\title{
    Stacked barplot of temperature vs. phase proportions.
}

\description{
     This function makes a stacked barplot of phase proportions, typically of minerals with, or without, melt.
}

\usage{
    phasePropPlot(mat, renormalize = TRUE, col = NULL, palette = "jet.colors", 
    leg.pos = "bottomleft", leg.bg = "#FFFFFFAA", xlab = expression(Temperature~degree*C), 
    ylab = "Phase proportions", xlim = NULL, ylim = c(0, 1), border = "white", main="")
}

\arguments{
  \item{mat}{a numeric matrix with phase proportions in columns, and temperature in C in rows.}
  \item{renormalize}{logical, should be the data in \code{mat} renormalized to a sum of 1?}
  \item{col}{list of colours for each of the phases.}
  \item{palette}{palette name.}
  \item{leg.pos}{position of the legend.}
  \item{leg.bg}{background colour for the legend.}
  \item{xlab}{character or expression; label for the x axis}
  \item{ylab}{character or expression; label for the y axis.}
  \item{xlim}{limits for the x axis.}
  \item{ylim}{limits for the y axis.}
  \item{border}{colour for the border for each of the bars.}
  \item{main}{character; main title for the plot.}
}

\details{
    The input is a matrix with phase proportions in columns, their names in colnames and variable (by default 
    a temperature in °C) in rownames.
    
    If '\code{col = NULL}' and '\code{palette}' is specified, then the corresponding number of colours are
    taken therefrom. Then the first column of data, typically a melt, is shown in gray.  

    \if{html}{\figure{phasePropPlot.png}} 
    \if{latex}{\figure{phasePropPlot.png}{options: width=4.5in}}
    
    The function assigns data for the diagram into a Figaro template 
    (list '\code{sheet}'), centers of intervals into '\code{x.data}' (not used for the x axis labeling)
    and the plotting matrix into '\code{y.data}'. 
    The values for labeling the x axis are taken from  rownames 
    of '\code{y.data}'.
}

\value{
  \item{sheet}{list with Figaro Style Sheet data.}
  \item{x.data}{See Details.}
  \item{y.data}{See Details.}
}


\author{
 Vojtech Janousek, \email{vojtech.janousek@geology.cz}
}

\seealso{
  \link{figaro}
}

\examples{
    min.prop<-matrix(c(0.1,0.2,0.5,
                   0.2,0.25,0.25,
                   0.5,0.4,0.15,
                   0.2,0.15,0.1),
        nrow=3,ncol=4,dimnames=list(seq(750,850,by=50),c("Liq","Cpx","Opx","Pl")))

    phasePropPlot(min.prop,palette="jet.colors", ylab="vol. percent", 
        main="Plot of mineral proportions")
    
    phasePropPlot(min.prop,col=1:4)
    
    phasePropPlot(min.prop,col=heat.colors(4))
    
    data(blatna)
    accessVar("blatna")
    windows(10,5)
    i<-names(sort(WR[,"SiO2"]))
    phasePropPlot(WR[i,major])
}

\keyword{hplot}
\concept{Plot}
\concept{Edit}
\concept{Menu: Data handling}
